Usage
divergeZimage(ob, out=FALSE, file="divergeZimage.pdf",
lin = 1, title = "", center = 0,
x2 = vector(), x= vector(),
plainmat = FALSE, ylab="wavelength (nm)",
xlab = "time (ns)")Arguments
ob
either an object of class dat or a numeric matrix; if a
numeric matrix is given then set plainmat=TRUE and specify labels
for the columns of matrix in x2 and for the rows of the matrix in
x
out
a logical indicating whether to write to the screen in the
case that this is possible or to a file; if TRUE, writes to a pdf
file
file
a character vector giving a filename to write to in the case
that out=TRUE
lin
range of x to plot linearly; values not
between -lin and lin are plotted on a log scale
title
character vector giving a title for the plot
center
point assigned to grey in the diverging palette.
x2
vector of labels for the columns of the matrix; used only if
plainmat=TRUE
x
vector of labels for the rows of the matrix; used only if
plainmat=TRUE
plainmat
logical indicating whether ob is a matrix, as
opposed to an object of class dat
ylab
character vector giving a label to put on the y-axis
xlab
character vector giving a label to put on the x-axis