Learn R Programming

TIMP (version 1.6)

efit2file: covert 'tim' FORTRAN efit files to a plain matrices

Description

'tim' efit files sometimes represent spectra associated with multiple datasets; for each matrix of spectra stored in such a file, this function writes a plain text file.

Usage

efit2file(filename, skip = 2, numcol, nrows=vector())

Arguments

filename
This is the path to the file to read in, as a quoted string.
skip
number of lines at the top of the file before the data begins
numcol
number of columns the data
nrows
a vector saying how many rows are in each of the matrices of spectra in the file; for instance nrows = c(256,256,256) would indicate that the file stores spectra associated with 3 datasets, each of which contains 256 wavelengths. If

See Also

readData