Usage
writeAverage(filename, ntimes, nwave, scans,
fileout = paste(filename, "Average.ivo", sep=""),
calibration = 1:nwave, wexplicit=FALSE)Arguments
filename
This is the path to the file to read in, as a quoted string.
ntimes
number of times in each scan
nwave
number of wavelengths in each scan
scans
number of full scans to read
fileout
a character vector specifying the filename to write
the averaged data to; the default is to write a file
named "filenameAverage.ivo"
calibration
a numeric vector representing the wavelength labels; by
default the labels "1, 2, ..., nwave" are used
wexplicit
logical whether the file is written in the
'wavelength explicit' format, with each column of the
matrix written representing a wavelength, as opposed to the
'time explicit' format, where each column represents a timepoint.