Learn R Programming

TIMP (version 1.6)

getResults: Functions to print and return parts of the object returned by the fitting routines.

Description

Functions to print and return parts of the object returned by fitModel. onls returns the output of the nls function. sumonls returns the result of calling summary on onls function. parEst returns a summary of model parameter estimates. The remaining functions return lists representing various aspects of the results returned by the function fitModel.

Usage

onls(result)
sumnls(result) 
parEst(result, param = "", dataset = NA, verbose = TRUE)
getXList(result)
getCLPList(result, getclperr = FALSE) 
getData(result, dataset = 1, weighted = FALSE)
getResiduals(result, dataset = 1)
getSVDResiduals(result, numsing = 2, dataset = 1)
getTraces(result, dataset = 1)
getdim1List(result) 
getdim2List(result)

Arguments

result
return value of fitModel
param
character vector of the particular parameters to return; if param=="" then all parameters are given.
dataset
index of the dataset from which to return results; by default dataset=NA in which case results from all datasets are returned
verbose
logical that defaults to TRUE that determines whether parEst just returns a list invisibly or prints as well.
getclperr
logical that defaults to FALSE that determines whether a list containing the standard error estimates associated with the conditionally linear parameters, as opposed to the conditionally linear parameters themselves
numsing
integer that defaults to 2; determines the number of singular vectors to return
weighted
logical indicating whether to return weighted or unweighted data

Value

  • sumnls returns an object of class "summary.nls". onls returns an object of class "nls". parEst returns an object of class "list" representing the parameter estimates.

    XList returns a "list" of length equal to the number of datasets modeled, where each element represents the matrix determined by the nonlinear parameters (under a kinetic model, the concentrations). CLPList returns a "list" of length equal to the number of datasets modeled, where each element represents the matrix determined as conditionally linear parameters (under a kinetic model, the spectra).

    getSVDData returns a "list" of length 3 with named elements values, left and right, where values contains the singular values, left contains numsing left singular vectors, and right contains numsing right singular vectors, all of the unweighted data. The number of singular vectors returned is determined by numsing. getData returns the dataset specified by the argument dataset (weighted data in the case that weighted=TRUE) as a "matrix" getResiduals returns a "matrix" of residuals for the dataset with index given by the argument dataset; the matrix returned has the dimension of the dataset itself.

    getSVDResiduals returns a "list" of length 3 with named elements values, left and right, where values contains the singular values, left contains numsing left singular vectors, and right contains numsing right singular vectors, all of the residuals. The number of singular vectors returned is determined by numsing. getTraces returns a "matrix" of model estimates for the dataset with index given by the argument dataset; the matrix returned has the dimension of the dataset itself.

    getdim1List returns a "list" of length equal to the number of datasets modeled, where each element is a "vector" of length equal to the number of x values in the dataset (times for kinetic models).

    getdim2List returns a "list" of length equal to the number of datasets modeled, where each element is a "vector" of length equal to the number of x2 values in the dataset (wavelengths for kinetic models).

See Also

fitModel