fitModel. Uses the
residuals in the fitted results to return a list of corrected
datasets to be used in place of the datasets used in the call
to fitModel as well as a list of weights. The data returned
contains the fitted values at pointed that are outliers and will be
assigned zero weight in subsequent fits.outlierCorr(oldRes, thresh=.8)fitModel function"numeric" determining what
points to consider outliers.dt, a list of
corrected datasets, and weightList, a list of new weight
matrices.xx
at a given value j of x2 that satisfy
thresh < resid[j,]/max(fitted[j,xx], max(fitted[j,xx])/10) .
Increasing thresh will assign fewer points as outliers.fitModel, preProcess